@@ -32,7 +32,7 @@ Here is a minimal deployable pattern definition:
 
 Typescript
 
-```typescript
+```python
 import { Construct } from 'constructs';
 import { Stack, StackProps } from 'aws-cdk-lib';
 import { FargateToStepfunctions, FargateToStepfunctionsProps } from '@aws-solutions-constructs/aws-fargate-stepfunctions';
@@ -166,6 +166,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_cloudwatch
@@ -187,8 +189,8 @@ class FargateToStepfunctions(
         id: builtins.str,
         *,
         public_api: builtins.bool,
-        state_machine_props: aws_cdk.aws_stepfunctions.StateMachineProps,
-        cluster_props: typing.Optional[aws_cdk.aws_ecs.ClusterProps] = None,
+        state_machine_props: typing.Union[aws_cdk.aws_stepfunctions.StateMachineProps, typing.Dict[str, typing.Any]],
+        cluster_props: typing.Optional[typing.Union[aws_cdk.aws_ecs.ClusterProps, typing.Dict[str, typing.Any]]] = None,
         container_definition_props: typing.Any = None,
         create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
         ecr_image_version: typing.Optional[builtins.str] = None,
@@ -198,9 +200,9 @@ class FargateToStepfunctions(
         existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
         fargate_service_props: typing.Any = None,
         fargate_task_definition_props: typing.Any = None,
-        log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
+        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
         state_machine_environment_variable_name: typing.Optional[builtins.str] = None,
-        vpc_props: typing.Optional[aws_cdk.aws_ec2.VpcProps] = None,
+        vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: -
@@ -221,6 +223,10 @@ class FargateToStepfunctions(
         :param state_machine_environment_variable_name: Optional Name for the container environment variable set to the ARN of the state machine. Default: - STATE_MACHINE_ARN
         :param vpc_props: Optional custom properties for a VPC the construct will create. This VPC will be used by the new Fargate service the construct creates (that's why targetGroupProps can't include a VPC). Providing both this and existingVpc is an error. A Step Functions Interface endpoint will be included in this VPC. Default: - A set of defaults from vpc-defaults.ts: DefaultPublicPrivateVpcProps() for public APIs and DefaultIsolatedVpcProps() for private APIs.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(FargateToStepfunctions.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = FargateToStepfunctionsProps(
             public_api=public_api,
             state_machine_props=state_machine_props,
@@ -300,8 +306,8 @@ class FargateToStepfunctionsProps:
         self,
         *,
         public_api: builtins.bool,
-        state_machine_props: aws_cdk.aws_stepfunctions.StateMachineProps,
-        cluster_props: typing.Optional[aws_cdk.aws_ecs.ClusterProps] = None,
+        state_machine_props: typing.Union[aws_cdk.aws_stepfunctions.StateMachineProps, typing.Dict[str, typing.Any]],
+        cluster_props: typing.Optional[typing.Union[aws_cdk.aws_ecs.ClusterProps, typing.Dict[str, typing.Any]]] = None,
         container_definition_props: typing.Any = None,
         create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
         ecr_image_version: typing.Optional[builtins.str] = None,
@@ -311,9 +317,9 @@ class FargateToStepfunctionsProps:
         existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
         fargate_service_props: typing.Any = None,
         fargate_task_definition_props: typing.Any = None,
-        log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
+        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
         state_machine_environment_variable_name: typing.Optional[builtins.str] = None,
-        vpc_props: typing.Optional[aws_cdk.aws_ec2.VpcProps] = None,
+        vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param public_api: Whether the construct is deploying a private or public API. This has implications for the VPC deployed by this construct. Default: - none
@@ -340,6 +346,23 @@ class FargateToStepfunctionsProps:
             log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
         if isinstance(vpc_props, dict):
             vpc_props = aws_cdk.aws_ec2.VpcProps(**vpc_props)
+        if __debug__:
+            type_hints = typing.get_type_hints(FargateToStepfunctionsProps.__init__)
+            check_type(argname="argument public_api", value=public_api, expected_type=type_hints["public_api"])
+            check_type(argname="argument state_machine_props", value=state_machine_props, expected_type=type_hints["state_machine_props"])
+            check_type(argname="argument cluster_props", value=cluster_props, expected_type=type_hints["cluster_props"])
+            check_type(argname="argument container_definition_props", value=container_definition_props, expected_type=type_hints["container_definition_props"])
+            check_type(argname="argument create_cloud_watch_alarms", value=create_cloud_watch_alarms, expected_type=type_hints["create_cloud_watch_alarms"])
+            check_type(argname="argument ecr_image_version", value=ecr_image_version, expected_type=type_hints["ecr_image_version"])
+            check_type(argname="argument ecr_repository_arn", value=ecr_repository_arn, expected_type=type_hints["ecr_repository_arn"])
+            check_type(argname="argument existing_container_definition_object", value=existing_container_definition_object, expected_type=type_hints["existing_container_definition_object"])
+            check_type(argname="argument existing_fargate_service_object", value=existing_fargate_service_object, expected_type=type_hints["existing_fargate_service_object"])
+            check_type(argname="argument existing_vpc", value=existing_vpc, expected_type=type_hints["existing_vpc"])
+            check_type(argname="argument fargate_service_props", value=fargate_service_props, expected_type=type_hints["fargate_service_props"])
+            check_type(argname="argument fargate_task_definition_props", value=fargate_task_definition_props, expected_type=type_hints["fargate_task_definition_props"])
+            check_type(argname="argument log_group_props", value=log_group_props, expected_type=type_hints["log_group_props"])
+            check_type(argname="argument state_machine_environment_variable_name", value=state_machine_environment_variable_name, expected_type=type_hints["state_machine_environment_variable_name"])
+            check_type(argname="argument vpc_props", value=vpc_props, expected_type=type_hints["vpc_props"])
         self._values: typing.Dict[str, typing.Any] = {
             "public_api": public_api,
             "state_machine_props": state_machine_props,
